@@ -139,6 +139,7 @@ class Converter(object):
                     'event', 'transient', 'name', 'supernova', 'sne', 'id',
                     'identifier', 'object']),
                 (ENTRY.REDSHIFT, ['redshift']),
+                (ENTRY.HOST, ['host']),
                 (ENTRY.LUM_DIST, [
                     'lumdist', 'luminosity distance', 'distance']),
                 (ENTRY.COMOVING_DIST, ['comoving distance']),
@@ -146,7 +147,7 @@ class Converter(object):
                 (ENTRY.DEC, ['dec', 'declination']),
                 (ENTRY.EBV, ['ebv', 'extinction']),
                 # At the moment transient-specific keys are not in astrocats.
-                ('claimedtype', [
+                (Key('claimedtype', KEY_TYPES.STRING), [
                     'claimedtype', 'type', 'claimed_type', 'claimed type'])
             ))
 
@@ -183,7 +184,8 @@ class Converter(object):
             PHOTOMETRY.BAND, PHOTOMETRY.INSTRUMENT, PHOTOMETRY.TELESCOPE]
         self._entry_keys = [
             ENTRY.COMOVING_DIST, ENTRY.REDSHIFT, ENTRY.LUM_DIST,
-            ENTRY.RA, ENTRY.DEC, ENTRY.EBV, 'claimedtype']
+            ENTRY.RA, ENTRY.DEC, ENTRY.EBV, ENTRY.HOST, Key(
+                'claimedtype', KEY_TYPES.STRING)]
         self._use_mc = False
         self._month_rep = re.compile(
             r'\b(' + '|'.join(self._MONTH_IDS.keys()) + r')\b')
@@ -1023,6 +1025,7 @@ class Converter(object):
             akeys.remove(PHOTOMETRY.BAND)
             akeys.remove(PHOTOMETRY.INSTRUMENT)
             akeys.remove(PHOTOMETRY.TELESCOPE)
+            akeys.append(ENTRY.NAME)
 
         # Make sure `E_` keys always appear after the actual measurements.
         if (PHOTOMETRY.MAGNITUDE in akeys and
